@@ -13,7 +13,7 @@
 #'
 #' @section Aesthetics:
 #' `geom_edge_diagonal` and `geom_edge_diagonal0` understand the following
-#' aesthetics. Bold aesthetics are automatically set, but can be overridden.
+#' aesthetics. Bold aesthetics are automatically set, but can be overwritten.
 #'
 #' - **x**
 #' - **y**
@@ -27,7 +27,7 @@
 #' - filter
 #'
 #' `geom_edge_diagonal2` understand the following aesthetics. Bold aesthetics are
-#' automatically set, but can be overridden.
+#' automatically set, but can be overwritten.
 #'
 #' - **x**
 #' - **y**
@@ -76,9 +76,9 @@
 #'
 #' @examples
 #' require(tidygraph)
-#' gr <- create_tree(20, 4) %>%
-#'   mutate(class = sample(letters[1:3], n(), replace = TRUE)) %>%
-#'   activate(edges) %>%
+#' gr <- create_tree(20, 4) |>
+#'   mutate(class = sample(letters[1:3], n(), replace = TRUE)) |>
+#'   activate(edges) |>
 #'   mutate(class = sample(letters[1:3], n(), replace = TRUE))
 #'
 #' ggraph(gr, 'tree') +
@@ -136,9 +136,9 @@ geom_edge_diagonal <- function(mapping = NULL, data = get_edges(),
     geom = GeomEdgePath, position = position, show.legend = show.legend,
     inherit.aes = FALSE,
     params = expand_edge_aes(
-      list(
+      list2(
         arrow = arrow, lineend = lineend, linejoin = linejoin,
-        linemitre = linemitre, na.rm = FALSE, n = n,
+        linemitre = linemitre, n = n,
         interpolate = FALSE, flipped = flipped, strength = strength,
         label_colour = label_colour, label_alpha = label_alpha,
         label_parse = label_parse, check_overlap = check_overlap,
@@ -189,9 +189,9 @@ geom_edge_diagonal2 <- function(mapping = NULL, data = get_edges('long'),
     geom = GeomEdgePath, position = position, show.legend = show.legend,
     inherit.aes = FALSE,
     params = expand_edge_aes(
-      list(
+      list2(
         arrow = arrow, lineend = lineend, linejoin = linejoin,
-        linemitre = linemitre, na.rm = FALSE, n = n,
+        linemitre = linemitre, n = n,
         interpolate = TRUE, flipped = flipped, strength = strength,
         label_colour = label_colour, label_alpha = label_alpha,
         label_parse = label_parse, check_overlap = check_overlap,
@@ -231,8 +231,8 @@ geom_edge_diagonal0 <- function(mapping = NULL, data = get_edges(),
     geom = GeomEdgeBezier, position = position, show.legend = show.legend,
     inherit.aes = FALSE,
     params = expand_edge_aes(
-      list(
-        arrow = arrow, lineend = lineend, na.rm = FALSE, strength = strength,
+      list2(
+        arrow = arrow, lineend = lineend, strength = strength,
         flipped = flipped, ...
       )
     )
